from checkplz.exceptions import CheckException, CheckExceptionGroup


class Checker:
    """ Base checker class """

    def __init__(self, methods: list):
        self.methods = methods

    def check(self, object_to_check, **kwargs):
        captured = []
        for method in self.methods:
            try:
                method(object_to_check, **kwargs)
            except CheckException as ce:
                captured.append(ce)

        if captured:
            raise CheckExceptionGroup(
                '\n' + '\n'.join([f" - {x.__class__.__name__}: {str(x)}" for x in captured])
            )
        else:
            return object_to_check
