import datetime

from checkplz.exceptions import BadEntry, FailedCheck


def integer_sequence(sequence: list, sort=False) -> list:
    """
    Provide a list of integers to be checked for appropriate sequencing. If any value in the sequence is not
    sequential (e.g. 3 is followed by 5) then an exception will be raised. If no issues are found in the sequence,
    then the function will return the sequence. Elements of the sequence list may be passed as integers or ranges.

    :param sequence: a list of integers and/or ranges that make up a complete sequence of numbers
        - [1,2,3,4,5]
        - [1,range(2,5),5]
    :param sort: a switch to control whether the sequence should be sorted prior to checking for continuity. Defaults
    to False.
    """
    seq = []
    for x in sequence:
        if isinstance(x, int):
            seq.append(x)
        elif isinstance(x, range):
            seq.extend(x)
        else:
            raise BadEntry(f"Value {x} is not of type integer or range")

    if sort:
        seq = sorted(seq)

    for ix, x in enumerate(seq):
        if ix + 1 < len(seq):  # do not try to compare the last entry to anything
            if not x + 1 == seq[ix + 1]:
                raise FailedCheck(f"{x} followed by {seq[ix + 1]}")
    return sequence


def past_or_present(time: datetime.datetime):
    if time <= datetime.datetime.now():
        pass
    else:
        raise FailedCheck(f"Time {time} is not in the past or present")
    return time
