import pytest

import checkplz
from checkplz.exceptions import CheckException, CheckExceptionGroup


# noinspection PyUnusedLocal
def check_exception_fail(object_to_check, **kwargs):
    raise CheckException


# noinspection PyUnusedLocal
def other_exception_fail(object_to_check, **kwargs):
    raise Exception


def test_check_exception():
    """
    CheckExceptions are collected from all methods and returned as a list of
    exceptions in a CheckExceptionGroup
    """
    c = checkplz.Checker([check_exception_fail])
    with pytest.raises(CheckExceptionGroup):
        c.check(None)


def test_other_exception():
    """ Non-CheckExceptions are raised as regular exceptions """
    c = checkplz.Checker([other_exception_fail])
    with pytest.raises(Exception):
        c.check(None)


def test_mixed_exception():
    """
    Non-CheckExceptions that occur after CheckExceptions result in the raising
    of a regular Exception, and the CheckExceptions are not raised
    """
    c = checkplz.Checker([check_exception_fail, other_exception_fail])
    with pytest.raises(Exception):
        c.check(None)


def test_return():
    """
    When no exceptions are raised, the Checker check should return the same
    object that was passed to it.
    """

    # noinspection PyUnusedLocal
    def pass_through(object_to_check, **kwargs):
        return object_to_check

    c = checkplz.Checker([pass_through])
    assert 1 == c.check(1)
