import pytest

from checkplz.exceptions import FailedCheck, BadEntry
from checkplz.methods import integer_sequence


def test_identical_return():
    o = [1, 2, 3]
    assert o == integer_sequence(o)


def test_simple_list():
    assert integer_sequence([1, 2, 3, 4, 5])


def test_simple_range():
    assert integer_sequence([1, range(2, 5), 5])


def test_unsorted_expected():
    assert integer_sequence([3, 2, 1], sort=True)


def test_unsorted_expected_range():
    assert integer_sequence([range(3, 5), 1, 2], sort=True)


def test_unsorted_unexpected():
    with pytest.raises(FailedCheck):
        integer_sequence([3, 2, 1])


def test_unsorted_unexpected_range():
    with pytest.raises(FailedCheck):
        integer_sequence([range(3, 5), 2, 1])


def test_bad_sequence():
    with pytest.raises(FailedCheck):
        integer_sequence([1, 4, 5])


def test_bad_unsorted():
    with pytest.raises(FailedCheck):
        integer_sequence([5, 4, 1])


def test_bad_entry_str():
    with pytest.raises(BadEntry):
        integer_sequence([5, 4, '1'])


def test_bad_entry_list():
    with pytest.raises(BadEntry):
        integer_sequence([5, 4, [1, 2, 3]])
